@@ -47,7 +47,6 @@ requests_ntlm = None
 requests_oauthlib = None
 oauth2 = None
 jwt = None
-default_backend = None
 serialization = None
 
 LOGGER = logging.getLogger(__file__)
@@ -884,10 +883,6 @@ class DCOSAuthTokenReader(object):
     def read(self, **request):
         if self._token is None or 'error' in request:
             with open(self._private_key_path, 'rb') as f:
-                global default_backend
-                if default_backend is None:
-                    from cryptography.hazmat.backends import default_backend
-
                 global serialization
                 if serialization is None:
                     from cryptography.hazmat.primitives import serialization
@@ -896,7 +891,7 @@ class DCOSAuthTokenReader(object):
                 if jwt is None:
                     import jwt
 
-                private_key = serialization.load_pem_private_key(f.read(), password=None, backend=default_backend())
+                private_key = serialization.load_pem_private_key(f.read(), password=None)
 
                 serialized_private = private_key.private_bytes(
                     encoding=serialization.Encoding.PEM,
